@@ -4,7 +4,7 @@ from typing import Optional, Union
 import numpy as np
 import pandas as pd
 
-from .utils import check_data_columns, localize_naive_timestamp
+from .utils import check_data_columns, get_local_tz
 
 
 def active_percent(
@@ -14,7 +14,7 @@ def active_percent(
     range_type: str = "automatic",
     ndays: int = 14,
     consistent_end_date: Optional[Union[str, datetime]] = None,
-) -> pd.DataFrame|dict[str:float]:
+) -> pd.DataFrame | dict[str:float]:
     """
     Calculate percentage of time CGM was active.
 
@@ -86,25 +86,20 @@ def active_percent(
     # Process each subject
     for subject in data["id"].unique():
         # Filter data for current subject and remove NA values
-        sub_data = (
-            data[data["id"] == subject]
-            .dropna(subset=["gl", "time"])
-            .sort_values("time")
-        )
+        sub_data = data[data["id"] == subject].dropna(subset=["gl", "time"]).sort_values("time")
 
         timeseries = sub_data.set_index("time")["gl"]
         active_percent_dict = active_percent_single(timeseries, dt0, tz, range_type, ndays, consistent_end_date)
         active_percent_dict["id"] = subject
         active_perc_data.append(active_percent_dict)
 
-
     # Convert to DataFrame
     df = pd.DataFrame(active_perc_data)
-    df = df[['id'] + [col for col in df.columns if col != 'id']]
+    df = df[["id"] + [col for col in df.columns if col != "id"]]
     return df
 
 
-def active_percent_single(
+def active_percent_single(  # noqa: C901
     data: pd.Series,
     dt0: Optional[int] = None,
     tz: str = "",
@@ -122,14 +117,18 @@ def active_percent_single(
     if not isinstance(data.index, pd.DatetimeIndex):
         raise ValueError("Series must have a DatetimeIndex")
 
+    # localize data.index to the timezone if it is not already
+    if data.index.tzinfo is None:
+        if not tz or tz == "":
+            tz = get_local_tz()
+        data.index = data.index.tz_localize(tz)
+
     data = data.dropna()
     if len(data) == 0:
         return {"active_percent": 0, "ndays": 0, "start_date": None, "end_date": None}
 
     # Calculate time differences between consecutive measurements
-    time_diffs = np.array(
-        data.index.diff().total_seconds() / 60
-    )  # Convert to minutes
+    time_diffs = np.array(data.index.to_series().diff().dt.total_seconds() / 60)  # Convert to minutes
 
     # Automatically determine dt0 if not provided
     if dt0 is None:
@@ -154,18 +153,24 @@ def active_percent_single(
         ndays = (max_time - min_time).total_seconds() / (24 * 3600)
 
         # Calculate active percentage
-        active_percent = (
-            (theoretical_gl_vals - missing_gl_vals) / theoretical_gl_vals
-        ) * 100
+        active_percent = ((theoretical_gl_vals - missing_gl_vals) / theoretical_gl_vals) * 100
     elif range_type == "manual":
         # Handle consistent end date if provided
         if consistent_end_date is not None:
-            end_date = localize_naive_timestamp(pd.to_datetime(consistent_end_date))
+            end_date = pd.to_datetime(consistent_end_date)
         else:
             end_date = data.index.max()
         start_date = end_date - pd.Timedelta(days=int(ndays))
 
         # Filter data to the specified date range
+        # bring timestamps to teh same timezone as start_date
+        tz = data.index.tz
+        # Localize start_date only if it is naive and tz is not None
+        if start_date.tzinfo is None and tz is not None:
+            start_date = start_date.tz_localize(tz)
+        # Localize end_date only if it is naive and tz is not None
+        if end_date.tzinfo is None and tz is not None:
+            end_date = end_date.tz_localize(tz)
         mask = (data.index >= start_date) & (data.index <= end_date)
         data = data[mask]
 
@@ -178,6 +183,3 @@ def active_percent_single(
         raise ValueError(f"Invalid range_type: {range_type}")
 
     return {"active_percent": active_percent, "ndays": round(ndays, 1), "start_date": min_time, "end_date": max_time}
-
-
-
